import React, { useEffect, useState } from 'react';
import { StyleSheet, View, Modal, Text, ScrollView, Dimensions, TouchableOpacity, TextInput } from 'react-native';
import { FlagImage } from '../FlagImage';
import countries from '../../data/countries.json';
export const CountryModalSelector = _ref => {
  let {
    setModalVisible,
    modalVisible,
    setSelectedCountry,
    modalStyle
  } = _ref;
  const styles = StyleSheet.create({
    modalView: modalStyle,
    itemCountry: {
      paddingVertical: 15,
      flexDirection: 'row',
      alignItems: 'center',
      justifyContent: 'space-between'
    },
    countryCode: {
      fontSize: 20,
      marginLeft: 10
    },
    itemCountryText: {
      fontSize: 20,
      flex: 0.6
    },
    visualInformation: {
      flexDirection: 'row',
      flex: 0.3,
      alignItems: 'center'
    },
    line: {
      borderBottomColor: 'black',
      borderBottomWidth: StyleSheet.hairlineWidth
    },
    backgroundModal: {
      backgroundColor: '#9e9e9ea7',
      position: 'absolute',
      width: Dimensions.get('screen').width,
      height: Dimensions.get('screen').height
    },
    searchInput: {
      borderColor: '#9d9d9d',
      borderWidth: 2,
      padding: 10,
      borderRadius: 10,
      marginBottom: 20
    }
  });
  const [modalCountries, setCountries] = useState(countries);

  const searchCountry = countryName => {
    const countriesSearched = countries.filter(country => country.country_name.includes(countryName));
    setCountries(countriesSearched);
  };

  useEffect(() => {
    setCountries(countries);
  }, [modalVisible]);

  const renderItem = item => {
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      key: item.id,
      onPress: () => {
        setModalVisible(false);
        setSelectedCountry(item.flag);
      }
    }, /*#__PURE__*/React.createElement(View, {
      style: styles.itemCountry
    }, /*#__PURE__*/React.createElement(View, {
      style: styles.visualInformation
    }, /*#__PURE__*/React.createElement(FlagImage, {
      flagCode: item.flag
    })), /*#__PURE__*/React.createElement(Text, {
      style: styles.itemCountryText
    }, item.country_name)), /*#__PURE__*/React.createElement(View, {
      style: styles.line
    }));
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Modal, {
    animationType: "slide",
    transparent: true,
    visible: modalVisible,
    onRequestClose: () => setModalVisible(false)
  }, /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: styles.backgroundModal,
    onPress: () => setModalVisible(false)
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.modalView
  }, /*#__PURE__*/React.createElement(TextInput, {
    style: styles.searchInput,
    onChangeText: searchCountry,
    placeholder: "search your country"
  }), /*#__PURE__*/React.createElement(ScrollView, null, modalCountries.map(country => renderItem(country)))))));
};
export default CountryModalSelector;
//# sourceMappingURL=index.js.map